EagleEyeMatcher class

A matcher finds the configuration item that applies to a given file path.

The EagleEyeMatcher scans through all EagleEyeConfigItems defined in the provided EagleEyeConfig and returns the first one whose filePattern matches the given file path. It uses RegexHelper for regex-based matching.

Constructors

EagleEyeMatcher({required EagleEyeConfig config, required RegexHelper regexHelper})
Creates a new EagleEyeMatcher instance with the provided config and regexHelper.

Properties

config EagleEyeConfig
The configuration containing all available rule items.
final
hashCode int
The hash code for this object.
no setterinherited
regexHelper RegexHelper
Helper class used to perform regex-based pattern matching.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

find(String filePath) EagleEyeConfigItem?
Finds the first EagleEyeConfigItem whose filePattern matches the given filePath.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited