ConfigKeys class

Define the configuration keys used by the developer when the configuration file is created.

Constructors

ConfigKeys()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

dependenciesAllowedEagleItemKey → const String
JSON key for enabling or disabling all dependencies in a rule item.
exclusiveDependenciesEagleItemKey → const String
JSON key for the list of allowed dependency patterns.
filePatternEagleItemKey → const String
JSON key for the file-matching pattern.
forbiddenDependenciesEagleItemKey → const String
JSON key for the list of forbidden dependency patterns.
nameEagleItemKey → const String
JSON key for the optional human-readable rule name.