ApplicationNameNotFoundException class

ApplicationNameNotFoundException defines an exception when the application name is not specified at pubspec.yaml file.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
User friendly message describing the issue.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited