Violation class
Represents a single architecture violation detected during analysis.
Constructors
Properties
- columnNumber → int
-
Column number (1-based) where the violation occurred.
final
- description → String
-
Human-readable description of the violation.
final
- filePath → String
-
Path of the file containing the violation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- importUri → String?
-
The import URI that triggered the violation, if applicable.
final
- lineNumber → int
-
Line number (1-based) where the violation occurred.
final
- ruleName → String?
-
Optional human-readable name from the config rule.
final
- ruleType → RuleType
-
Which rule type was violated.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited